package com.css.simulation.resource.scheduler.common.configuration.init;

import api.common.util.CollectionUtil;
import com.css.simulation.resource.scheduler.common.configuration.kubernetes.KubernetesConfiguration;
import com.css.simulation.resource.scheduler.common.util.KubernetesUtil;
import com.css.simulation.resource.scheduler.service.domain.KubernetesNodeTO;
import io.kubernetes.client.openapi.ApiClient;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;

@Component
@Slf4j
public class CustomApplicationRunner implements ApplicationRunner {
    @Resource
    private KubernetesConfiguration kubernetesConfiguration;
    @Resource
    private ApiClient apiClient;
    @Resource
    private StringRedisTemplate stringRedisTemplate;


    @Override
    public void run(ApplicationArguments args) {
        List<KubernetesNodeTO> initialNodeList = kubernetesConfiguration.getNodeList();
        List<String> podNameList = KubernetesUtil.getPod(apiClient, kubernetesConfiguration.getNamespace());
        if (CollectionUtil.isEmpty(podNameList)) {
            for (KubernetesNodeTO kubernetesNodeTO : initialNodeList) {
                stringRedisTemplate.opsForValue().set("node:" + kubernetesNodeTO.getName() + ":parallelism", kubernetesNodeTO.getMaxParallelism() + "");
            }
            log.info("重置节点并行度为：" + initialNodeList);
        }

    }
}